try_restart

Function try_restart 

pub async fn try_restart() -> bool
Available on crate feature global_instance only.
Attempts to notify a restart on the global controller.

Returns true if the notify succeeded, false if already notified.

Equivalent to calling SoftCycleController::try_notify(SoftCycleMessage::Restart) on the global instance.