Module payload

Module payload 

Atomic payload types and the Payload trait for use with crate::SoftCycleController.

Structs

AtomicConstPtr
Atomic storage for *const T. Used as Payload::UnderlyingAtomic for *const T.
AtomicUnit
Atomic storage for (). Used as Payload::UnderlyingAtomic for the unit type.

Traits

AtomicPrimitive
Trait for atomic wrapper types used as the storage for controller payloads.
Payload
Trait for payload types that can be stored and loaded atomically by the SoftCycleController.