pub struct SoftCycleListener<'a, T: Payload> { /* private fields */ }Expand description
Future that completes when a notification from the associated controller is observed.
Returned by SoftCycleController::listener. Resolves to Ok(payload) when a notification
is observed. If the controller is already notified when the listener is created or first
polled, it may complete immediately with that payload. If multiple notify/clear cycles
occur after the listener is created, it returns one of those payloads (no guarantee of
returning the earliest or latest). See the crate-level documentation for full
completion guarantees.